@@ -208,6 +208,26 @@ class CoordinatesDisplacement(object):
             
         return self.enu
 
+    def get_absolute_position(self) -> Coordinates:
+        """
+        >>> enu = ENU(0.096,0.010,0.144)
+        >>> ref_position = Coordinates(4889803.653, 170755.706, 4078049.851)
+        >>> c = CoordinatesDisplacement(enu=enu, ref_position=ref_position)
+        >>> position = c.get_absolute_position()
+        >>> '{:.3f} {:.3f} {:.3f}'.format(*position.xyz())
+        '4889803.753 170755.806 4078049.951'
+        >>> c_displacement = CoordinatesDisplacement.from_positions(ref_position, position)
+        >>> '{:.1f} {:.1f} {:.1f}'.format(*c_displacement.get_xyz())
+        '0.1 0.1 0.1'
+        """
+
+        xyz = lla_to_xyz(self.ref_lla.longitude, self.ref_lla.latitude, self.ref_lla.altitude, radians=True) 
+
+        dxyz = self.get_xyz()
+
+        return Coordinates.from_xyz(xyz[0] + dxyz[0], xyz[1] + dxyz[1], xyz[2] + dxyz[2])
+
+
     def __abs__(self) -> float:
         """
         >>> c = CoordinatesDisplacement.from_xyz(0.1, 0.1, 0.1)
